@@ -5,7 +5,6 @@ from hatchling.builders.hooks.plugin.interface import BuildHookInterface
 from .msgfmt import make
 from tempfile import TemporaryDirectory
 from pathlib import Path
-import subprocess
 
 class MsgfmtBuildHook(BuildHookInterface):
     PLUGIN_NAME = 'msgfmt'
@@ -28,11 +27,11 @@ class MsgfmtBuildHook(BuildHookInterface):
         print(f'{build_data=}')
         print(f'{self.directory=}')
         print(f'{self.build_config.directory=}')
-        subprocess.run(['find', self.build_config.directory], check=True)
         print(f'{self.build_config.default_include()=}')
         print(f'{self.build_config.default_exclude()=}')
         print(f'{self.build_config.default_only_include()=}')
         print(f'{self.build_config.default_packages()=}')
+        print(f'{self.build_config.sources=}')
 
     def finalize(self, version: str, build_data: dict[str, Any], artifact_path: str) -> None:
         if self.target_name != 'wheel':
@@ -43,11 +42,11 @@ class MsgfmtBuildHook(BuildHookInterface):
         print(f'{artifact_path=}')
         print(f'{self.directory=}')
         print(f'{self.build_config.directory=}')
-        subprocess.run(['find', self.build_config.directory], check=True)
         print(f'{self.build_config.default_include()=}')
         print(f'{self.build_config.default_exclude()=}')
         print(f'{self.build_config.default_only_include()=}')
         print(f'{self.build_config.default_packages()=}')
+        print(f'{self.build_config.sources=}')
 
 @hookimpl
 def hatch_register_build_hook():
